@@ -31,12 +31,10 @@ class Calculate(object):
     
     @regcmd('@calc (?P<exp>.+)$')
     def calculate(self, server, nick, user, host, target, msg, exp):
-        req  = self.client.query(exp)
-        data = ''
-        for pod in req:
-            if pod.text:
-                data = '%s %s' % (data, pod.text)
-        send_lines(server, target, data)
+        for pod in self.client.query(exp):
+            if getattr(pod, 'text', None):
+                send_lines(server, target,
+                    pod.text.encode('utf-8'))
     
 install = Calculate
 
@@ -47,3 +45,5 @@ install = Calculate
 
 
 
+
+
